@@ -31,39 +31,9 @@ extern "C" {
 #include "asterisk/bridge.h"
 #include "asterisk/pbx.h"
 
-/*!
- * \brief Structure that contains a snapshot of information about a bridge
- */
-struct ast_bridge_snapshot {
-	AST_DECLARE_STRING_FIELDS(
-		/*! Immutable bridge UUID. */
-		AST_STRING_FIELD(uniqueid);
-		/*! Bridge technology that is handling the bridge */
-		AST_STRING_FIELD(technology);
-		/*! Bridge subclass that is handling the bridge */
-		AST_STRING_FIELD(subclass);
-		/*! Creator of the bridge */
-		AST_STRING_FIELD(creator);
-		/*! Name given to the bridge by its creator */
-		AST_STRING_FIELD(name);
-		/*! Unique ID of the channel providing video, if one exists */
-		AST_STRING_FIELD(video_source_id);
-	);
-	/*! AO2 container of bare channel uniqueid strings participating in the bridge.
-	 * Allocated from ast_str_container_alloc() */
-	struct ao2_container *channels;
-	/*! Bridge flags to tweak behavior */
-	struct ast_flags feature_flags;
-	/*! Bridge capabilities */
-	uint32_t capabilities;
-	/*! Number of channels participating in the bridge */
-	unsigned int num_channels;
-	/*! Number of active channels in the bridge. */
-	unsigned int num_active;
-	/*! The video mode of the bridge */
-	enum ast_bridge_video_mode_type video_mode;
-	/*! The time of bridge creation */
-	struct timeval creationtime;
+struct ast_bridge_snapshot_update {
+	struct ast_bridge_snapshot *old_snapshot;
+	struct ast_bridge_snapshot *new_snapshot;
 };
 
 /*!
@@ -75,7 +45,7 @@ struct ast_bridge_snapshot {
  *
  * \param bridge The bridge from which to generate a snapshot
  *
- * \return AO2 refcounted snapshot on success
+ * \retval AO2 refcounted snapshot on success
  * \retval NULL on error
  */
 struct ast_bridge_snapshot *ast_bridge_snapshot_create(struct ast_bridge *bridge);
@@ -84,7 +54,7 @@ struct ast_bridge_snapshot *ast_bridge_snapshot_create(struct ast_bridge *bridge
  * \since 12
  * \brief Message type for \ref ast_bridge_snapshot.
  *
- * \return Message type for \ref ast_bridge_snapshot.
+ * \retval Message type for \ref ast_bridge_snapshot.
  */
 struct stasis_message_type *ast_bridge_snapshot_type(void);
 
@@ -96,50 +66,18 @@ struct stasis_message_type *ast_bridge_snapshot_type(void);
  *
  * \param bridge Bridge for which to get a topic or \c NULL.
  *
- * \return Topic for bridge's events.
+ * \retval Topic for bridge's events.
  * \retval ast_bridge_topic_all() if \a bridge is \c NULL.
  */
 struct stasis_topic *ast_bridge_topic(struct ast_bridge *bridge);
 
-/*!
- * \since 12
- * \brief A topic which publishes the events for a particular bridge.
- *
- * \ref ast_bridge_snapshot messages are replaced with stasis_cache_update
- * messages.
- *
- * If the given \a bridge is \c NULL, ast_bridge_topic_all_cached() is returned.
- *
- * \param bridge Bridge for which to get a topic or \c NULL.
- *
- * \retval Topic for bridge's events.
- * \retval ast_bridge_topic_all() if \a bridge is \c NULL.
- */
-struct stasis_topic *ast_bridge_topic_cached(struct ast_bridge *bridge);
-
 /*!
  * \since 12
  * \brief A topic which publishes the events for all bridges.
- * \return Topic for all bridge events.
+ * \retval Topic for all bridge events.
  */
 struct stasis_topic *ast_bridge_topic_all(void);
 
-/*!
- * \since 12
- * \brief A caching topic which caches \ref ast_bridge_snapshot messages from
- * ast_bridge_events_all(void).
- *
- * \retval Caching topic for all bridge events.
- */
-struct stasis_topic *ast_bridge_topic_all_cached(void);
-
-/*!
- * \since 12
- * \brief Backend cache for ast_bridge_topic_all_cached().
- * \retval Cache of \ref ast_bridge_snapshot.
- */
-struct stasis_cache *ast_bridge_cache(void);
-
 /*!
  * \since 12
  * \brief Publish the state of a bridge
@@ -160,7 +98,7 @@ struct ast_bridge_merge_message {
  * \since 12
  * \brief Message type for \ref ast_bridge_merge_message.
  *
- * \return Message type for \ref ast_bridge_merge_message.
+ * \retval Message type for \ref ast_bridge_merge_message.
  */
 struct stasis_message_type *ast_bridge_merge_message_type(void);
 
@@ -193,17 +131,17 @@ struct ast_bridge_blob {
 
 /*!
  * \since 12
- * \brief Message type for \ref ast_channel enter bridge blob messages.
+ * \brief Message type for \ref channel enter bridge blob messages.
  *
- * \return Message type for \ref ast_channel enter bridge blob messages.
+ * \retval Message type for \ref channel enter bridge blob messages.
  */
 struct stasis_message_type *ast_channel_entered_bridge_type(void);
 
 /*!
  * \since 12
- * \brief Message type for \ref ast_channel leave bridge blob messages.
+ * \brief Message type for \ref channel leave bridge blob messages.
  *
- * \return Message type for \ref ast_channel leave bridge blob messages.
+ * \retval Message type for \ref channel leave bridge blob messages.
  */
 struct stasis_message_type *ast_channel_left_bridge_type(void);
 
@@ -218,12 +156,10 @@ struct stasis_message_type *ast_channel_left_bridge_type(void);
  * \pre bridge is locked.
  * \pre No channels are locked.
  *
- * \param type
  * \param bridge Channel blob is associated with, or NULL for global/all bridges.
- * \param chan The channel that started the bridge
  * \param blob JSON object representing the data.
  * \return \ref ast_bridge_blob message.
- * \retval NULL on error
+ * \return \c NULL on error
  */
 struct stasis_message *ast_bridge_blob_create(struct stasis_message_type *type,
 	struct ast_bridge *bridge,
@@ -242,12 +178,11 @@ struct stasis_message *ast_bridge_blob_create(struct stasis_message_type *type,
  * \pre bridge is locked.
  * \pre No channels are locked.
  *
- * \param type
  * \param bridge_snapshot Bridge snapshot
- * \param chan_snapshot Channel snapshot
+ * \param channel_snapshot Channel snapshot
  * \param blob JSON object representing the data.
  * \return \ref ast_bridge_blob message.
- * \retval NULL on error
+ * \return \c NULL on error
  */
 struct stasis_message *ast_bridge_blob_create_from_snapshots(struct stasis_message_type *type,
 	struct ast_bridge_snapshot *bridge_snapshot,
@@ -287,7 +222,7 @@ void ast_bridge_publish_leave(struct ast_bridge *bridge, struct ast_channel *cha
  * \param sanitize The message sanitizer to use on the snapshot
  *
  * \return JSON object representing bridge snapshot.
- * \retval NULL on error
+ * \return \c NULL on error
  */
 struct ast_json *ast_bridge_snapshot_to_json(const struct ast_bridge_snapshot *snapshot,
 	const struct stasis_message_sanitizer *sanitize);
@@ -304,7 +239,7 @@ struct ast_bridge_channel_snapshot_pair {
  * \since 12
  * \brief Message type for \ref ast_blind_transfer_message.
  *
- * \return Message type for \ref ast_blind_transfer_message.
+ * \retval Message type for \ref ast_blind_transfer_message.
  */
 struct stasis_message_type *ast_blind_transfer_type(void);
 
@@ -335,8 +270,9 @@ struct ast_blind_transfer_message {
  *
  * \param is_external Whether the blind transfer was initiated externally (e.g. via AMI or native protocol)
  * \param transferer The transferer's channel that is bridged to the transferee
- * \param exten The destination extension for the blind transfer
+ * \param bridge The bridge the transferer and transferee are in
  * \param context The destination context for the blind transfer
+ * \param exten The destination extension for the blind transfer
  *
  * \retval NULL Failure to allocate or create snapshots
  * \retval non-NULL The created blind transfer message
@@ -349,7 +285,16 @@ struct ast_blind_transfer_message *ast_blind_transfer_message_create(int is_exte
  *
  * \pre Bridges involved are locked. Channels involved are not locked.
  *
- * \param transfer_message
+ * \param is_external Whether the blind transfer was initiated externally (e.g. via AMI or native protocol)
+ * \param result The success or failure of the transfer
+ * \param to_transferee The bridge between the transferer and transferee plus the transferer channel
+ * \param context The destination context for the blind transfer
+ * \param exten The destination extension for the blind transfer
+ * \param transferee_channel If a single channel is being transferred, this is it. If
+ *                           multiple parties are being transferred, this is NULL.
+ * \param replace_channel If multiple parties are being transferred or the transfer
+ *                        cannot reach across the bridge due to bridge flags, this is
+ *                        the channel connecting their bridge to the destination.
  */
 void ast_bridge_publish_blind_transfer(struct ast_blind_transfer_message *transfer_message);
 
@@ -508,25 +453,48 @@ void ast_bridge_publish_attended_transfer(struct ast_attended_transfer_message *
 struct stasis_message_type *ast_attended_transfer_type(void);
 
 /*!
- * \brief Returns the most recent snapshot for the bridge.
+ * \brief Returns the current snapshot for the bridge.
+ * \since 17.0
  *
  * The returned pointer is AO2 managed, so ao2_cleanup() when you're done.
  *
- * \param bridge_id Uniqueid of the bridge for which to get the snapshot.
+ * \param bridge_id Uniqueid of the bridge from which to get the snapshot.
  * \return Most recent snapshot. ao2_cleanup() when done.
- * \return \c NULL if channel isn't in cache.
+ * \return \c NULL if bridge or snapshot doesn't exist.
  */
-struct ast_bridge_snapshot *ast_bridge_snapshot_get_latest(
+struct ast_bridge_snapshot *ast_bridge_get_snapshot_by_uniqueid(
 	const char *bridge_id);
 
+/*!
+ * \brief Returns the current snapshot for the bridge.
+ * \since 17.0
+ *
+ * The returned pointer is AO2 managed, so ao2_cleanup() when you're done.
+ *
+ * \param bridge The bridge from which to get the snapshot.
+ * \return Most recent snapshot. ao2_cleanup() when done.
+ * \return \c NULL if there isn't a snapshot.
+ */
+struct ast_bridge_snapshot *ast_bridge_get_snapshot(
+	struct ast_bridge *bridge);
+
 /*!
  * \internal
  * \brief Initialize the topics for a single bridge.
- * \retval 0 on success.
- * \retval Non-zero on error.
+ * \return 0 on success.
+ * \return Non-zero on error.
  */
 int bridge_topics_init(struct ast_bridge *bridge);
 
+/*!
+ * \internal
+ * \since 17.0
+ * \brief Publish destroy then cleanup topics.
+ *
+ * \param bridge The bridge to clean up
+ */
+void bridge_topics_destroy(struct ast_bridge *bridge);
+
 /*!
  * \internal
  * \brief Initialize the stasis bridging topic and message types
